# Electron code

This folder contains the JS code that is executed by Electron

## Install How to install/update the dependencies

To install/update the code dependencies, instead of using `npm install` run `./install-dependencies.sh`. This way the
native dependencies are compiled for the current platform, something that is necessary for the code to run.
